; mitxela.com/projects/a_tiny_theremin


; PB0 / PB1 are the differential PWM outputs 
  ; I found it sometimes worked better in single-ended mode, 
  ; with the speaker ground connected to the chip ground.
  ; Possibly to do with my speakers' power supply

; PB2 is the detection pulse. 
  ; either connect to mains ground (if the power supply is isolated)
  ; or directly to your body. An ordinary ESD wriststrap probably won't
  ; work because it has a very high resistance in series, for safety.

; PB3 is pitch antenna
; PB4 is volume antenna

.include "tn85def.inc" 
rjmp init

; //////////////// TIMER0_COMPA interrupt /////////////////

.org $0A
	in r0,SREG
	ldi r24,0
	out TCNT0,r24
	
	; r3 is the capacitance reading
	; r4 is a running total to try and average the reading
	add r4,r3
	brcc endint		; wait until r4 overflows
	clr r4

	; advance phase of the sine wave
	; sine table is two dimensional, where ZH = phase, ZL= volume
	
	cpi ZH, HIGH(sineTable*2)+25	; end of table?
	brne dontReset
	ldi ZH, HIGH(sineTable*2)
dontReset:
	lpm r24,Z			; load the value and send it
	out OCR1A,r24		; to the PWM output
	inc ZH

endint:
	out SREG,r0
	reti


;///////////////  init   //////////////

init:
	ldi r16, 0b00000010
	out DDRB,r16


	; PLL output timer1
	ldi r16,(1<<PLLE|1<<PCKE)
	out PLLCSR,r16

	ldi r16, (1<<PWM1A|1<<COM1A0|1<<CS10)
	out TCCR1,r16
	ldi r16,0
	out OCR1A,r16
	ldi r16,255
	out OCR1C,r16
	
	; interrupt setup timer0
	ldi r16,(1<<CS00)
	out TCCR0B,r16
	ldi r16,(1<<OCIE0A)
	out TIMSK,r16
	ldi r16,1
	out OCR0A,r16

	ldi ZH, HIGH(sineTable*2)
	ldi ZL,  LOW(sineTable*2)


;///////////////  main loop  //////////////

main:
	sei
	rcall readCap1	; cap1 is pitch antenna
	mov r3,r16		; store for use in the interrupt

	
	rcall readCap2	; volume antenna
	; For volume we want an absolute number, not to advance a phase.
	; To try and average it a bit, make several readings and add them to r6
	add r6,r16		
	brcc mset1
	clr r6			; if it overflows, 
	dec r6			; clr/dec sets r6 to 255 (saturated)
	rjmp mset2		; and skip ahead

mset1:
	dec r5			; r5 is counting down the number of readings we've made
	brne main		; wait until it hits zero

mset2:
	ldi r16,10		; reset r5 to 10 - number of readings to average
	mov r5,r16
	
	lsr r6			; divide by two and set volume level
	mov ZL,r6		; (LPM takes place in the interrupt)
	clr r6


rjmp main



;///////////////  capacitance readings  ////////////////

.equ tPin=2

readCap1:
	ldi r16,(1<<ADLAR|1<<MUX1) ; Vcc, left adjust, PB4
	out ADMUX,r16

	cbi PORTB,4				; ground both pins
	cbi PORTB,tPin

	ldi r16, 0b00011111		; everything as output
	out DDRB,r16

	rcall wait

	cbi DDRB,4				; set antenna to high-impedance input

	rcall wait
	cli						; disable interrupts (timing critical)
	sbi PORTB,tPin			; set detection pin high

	rcall waitS				; wait a specific amount

	rcall readADC			; take the reading.

	ret


; same again on the other pin
readCap2:
	ldi r16,(1<<ADLAR|1<<MUX1|1<<MUX0) ; Vcc, left adjust, PB3
	out ADMUX,r16

	cbi PORTB,3
	cbi PORTB,tPin

	ldi r16, 0b00011111
	out DDRB,r16

	rcall wait

	cbi DDRB,3

	rcall wait
	cli
	sbi PORTB,tPin

	rcall waitS

	rcall readADC

	ret



readADC:
	; Enable, Start conversion, clear interrupt
	ldi r16,(1<<ADEN|1<<ADSC|1<<ADIF|1<<ADPS2)
	out ADCSRA,r16
	sei
waitForConversion:
	sbis ADCSRA,ADIF
	rjmp waitForConversion
	in r17,ADCL
	in r16,ADCH
	sbrc r17,7	; round up if low byte>=128
	inc r16
	ret




wait:
	ldi r17,10
waitL:
	dec r17
	brne waitL
	ret


; Wait times were determined just by trial and error
waitS:
	ldi r17,8	; This may not be the optimum value
waitSL:
	nop
	nop

	dec r17
	brne waitSL
	ret


.org 256  ; align with page
sineTable: 
; Phase is vertical, volume is horizontal
.db 128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 159,158,157,157,156,155,155,154,153,153,152,152,151,150,150,149,149,148,148,147,146,146,145,145,144,144,144,143,143,142,142,141,141,141,140,140,139,139,139,138,138,138,137,137,137,136,136,136,135,135,135,135,134,134,134,134,133,133,133,133,133,132,132,132,132,132,131,131,131,131,131,131,131,130,130,130,130,130,130,130,130,129,129,129,129,129,129,129,129,129,129,129,129,129,129,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 188,186,185,184,182,181,180,178,177,176,175,174,172,171,170,169,168,167,166,165,164,163,162,161,160,159,158,157,156,155,155,154,153,152,151,151,150,149,149,148,147,147,146,145,145,144,144,143,142,142,141,141,140,140,139,139,138,138,138,137,137,136,136,136,135,135,135,134,134,134,133,133,133,133,132,132,132,132,131,131,131,131,131,130,130,130,130,130,130,130,129,129,129,129,129,129,129,129,129,129,129,129,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 213,211,209,207,205,203,201,200,198,196,194,193,191,189,188,186,185,183,182,180,179,177,176,175,173,172,171,169,168,167,166,165,164,162,161,160,159,158,157,156,155,154,153,153,152,151,150,149,148,148,147,146,145,145,144,143,143,142,142,141,140,140,139,139,138,138,137,137,137,136,136,135,135,135,134,134,133,133,133,133,132,132,132,132,131,131,131,131,130,130,130,130,130,130,129,129,129,129,129,129,129,129,129,129,129,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 233,230,228,225,223,221,219,216,214,212,210,208,206,204,202,200,198,196,194,192,191,189,187,186,184,182,181,179,178,176,175,173,172,170,169,168,167,165,164,163,162,161,159,158,157,156,155,154,153,152,151,150,150,149,148,147,146,146,145,144,143,143,142,141,141,140,140,139,139,138,137,137,137,136,136,135,135,134,134,134,133,133,133,132,132,132,132,131,131,131,131,130,130,130,130,130,130,129,129,129,129,129,129,129,129,129,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 246,243,240,238,235,233,230,228,225,223,220,218,216,213,211,209,207,205,203,201,199,197,195,193,191,189,187,186,184,182,181,179,177,176,174,173,171,170,169,167,166,165,163,162,161,160,159,157,156,155,154,153,152,151,150,149,149,148,147,146,145,145,144,143,142,142,141,140,140,139,139,138,138,137,137,136,136,135,135,134,134,134,133,133,133,132,132,132,131,131,131,131,130,130,130,130,130,130,129,129,129,129,129,129,129,129,129,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 252,249,246,243,240,238,235,232,230,227,225,222,220,218,215,213,211,208,206,204,202,200,198,196,194,192,190,188,187,185,183,181,180,178,177,175,174,172,171,169,168,166,165,164,163,161,160,159,158,157,156,155,153,152,152,151,150,149,148,147,146,145,145,144,143,142,142,141,140,140,139,139,138,138,137,136,136,136,135,135,134,134,134,133,133,132,132,132,132,131,131,131,131,130,130,130,130,130,129,129,129,129,129,129,129,129,129,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 250,247,244,241,239,236,233,231,228,226,223,221,218,216,214,212,209,207,205,203,201,199,197,195,193,191,189,187,186,184,182,181,179,177,176,174,173,171,170,169,167,166,165,163,162,161,160,158,157,156,155,154,153,152,151,150,149,148,148,147,146,145,144,144,143,142,142,141,140,140,139,138,138,137,137,136,136,135,135,135,134,134,133,133,133,132,132,132,132,131,131,131,131,130,130,130,130,130,129,129,129,129,129,129,129,129,129,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 240,238,235,232,230,227,225,223,220,218,216,214,211,209,207,205,203,201,199,197,195,193,191,190,188,186,184,183,181,180,178,176,175,174,172,171,169,168,167,165,164,163,162,160,159,158,157,156,155,154,153,152,151,150,149,148,148,147,146,145,144,144,143,142,142,141,140,140,139,139,138,138,137,137,136,136,135,135,134,134,134,133,133,133,132,132,132,132,131,131,131,131,130,130,130,130,130,129,129,129,129,129,129,129,129,129,129,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 224,221,219,217,215,213,211,209,207,205,203,201,199,197,195,194,192,190,188,187,185,184,182,180,179,178,176,175,173,172,171,169,168,167,166,164,163,162,161,160,159,158,157,156,155,154,153,152,151,150,149,148,148,147,146,145,145,144,143,143,142,141,141,140,140,139,139,138,138,137,137,136,136,135,135,135,134,134,133,133,133,133,132,132,132,131,131,131,131,131,130,130,130,130,130,130,129,129,129,129,129,129,129,129,129,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 201,199,198,196,194,193,191,190,188,186,185,184,182,181,179,178,177,175,174,173,172,170,169,168,167,166,165,164,163,162,160,159,159,158,157,156,155,154,153,152,151,151,150,149,148,148,147,146,146,145,144,144,143,142,142,141,141,140,140,139,139,138,138,137,137,136,136,136,135,135,135,134,134,134,133,133,133,132,132,132,132,131,131,131,131,131,130,130,130,130,130,130,130,129,129,129,129,129,129,129,129,129,129,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 174,173,172,171,169,168,167,167,166,165,164,163,162,161,160,159,158,158,157,156,155,155,154,153,152,152,151,150,150,149,148,148,147,147,146,145,145,144,144,143,143,142,142,141,141,140,140,139,139,139,138,138,137,137,137,136,136,136,135,135,135,134,134,134,134,133,133,133,133,132,132,132,132,132,131,131,131,131,131,130,130,130,130,130,130,130,130,129,129,129,129,129,129,129,129,129,129,129,129,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 144,143,143,142,142,142,141,141,141,140,140,140,140,139,139,139,138,138,138,138,137,137,137,137,136,136,136,136,135,135,135,135,135,134,134,134,134,134,133,133,133,133,133,132,132,132,132,132,132,132,131,131,131,131,131,131,131,131,130,130,130,130,130,130,130,130,130,130,130,129,129,129,129,129,129,129,129,129,129,129,129,129,129,129,129,129,129,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 112,113,113,114,114,114,115,115,115,116,116,116,116,117,117,117,118,118,118,118,119,119,119,119,120,120,120,120,121,121,121,121,121,122,122,122,122,122,123,123,123,123,123,124,124,124,124,124,124,124,125,125,125,125,125,125,125,125,126,126,126,126,126,126,126,126,126,126,126,127,127,127,127,127,127,127,127,127,127,127,127,127,127,127,127,127,127,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 82,83,84,85,87,88,89,89,90,91,92,93,94,95,96,97,98,98,99,100,101,101,102,103,104,104,105,106,106,107,108,108,109,109,110,111,111,112,112,113,113,114,114,115,115,116,116,117,117,117,118,118,119,119,119,120,120,120,121,121,121,122,122,122,122,123,123,123,123,124,124,124,124,124,125,125,125,125,125,126,126,126,126,126,126,126,126,127,127,127,127,127,127,127,127,127,127,127,127,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 55,57,58,60,62,63,65,66,68,70,71,72,74,75,77,78,79,81,82,83,84,86,87,88,89,90,91,92,93,94,96,97,97,98,99,100,101,102,103,104,105,105,106,107,108,108,109,110,110,111,112,112,113,114,114,115,115,116,116,117,117,118,118,119,119,120,120,120,121,121,121,122,122,122,123,123,123,124,124,124,124,125,125,125,125,125,126,126,126,126,126,126,126,127,127,127,127,127,127,127,127,127,127,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 32,35,37,39,41,43,45,47,49,51,53,55,57,59,61,62,64,66,68,69,71,72,74,76,77,78,80,81,83,84,85,87,88,89,90,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,108,109,110,111,111,112,113,113,114,115,115,116,116,117,117,118,118,119,119,120,120,121,121,121,122,122,123,123,123,123,124,124,124,125,125,125,125,125,126,126,126,126,126,126,127,127,127,127,127,127,127,127,127,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 16,18,21,24,26,29,31,33,36,38,40,42,45,47,49,51,53,55,57,59,61,63,65,66,68,70,72,73,75,76,78,80,81,82,84,85,87,88,89,91,92,93,94,96,97,98,99,100,101,102,103,104,105,106,107,108,108,109,110,111,112,112,113,114,114,115,116,116,117,117,118,118,119,119,120,120,121,121,122,122,122,123,123,123,124,124,124,124,125,125,125,125,126,126,126,126,126,127,127,127,127,127,127,127,127,127,127,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 6,9,12,15,17,20,23,25,28,30,33,35,38,40,42,44,47,49,51,53,55,57,59,61,63,65,67,69,70,72,74,75,77,79,80,82,83,85,86,87,89,90,91,93,94,95,96,98,99,100,101,102,103,104,105,106,107,108,108,109,110,111,112,112,113,114,114,115,116,116,117,118,118,119,119,120,120,121,121,121,122,122,123,123,123,124,124,124,124,125,125,125,125,126,126,126,126,126,127,127,127,127,127,127,127,127,127,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 4,7,10,13,16,18,21,24,26,29,31,34,36,38,41,43,45,48,50,52,54,56,58,60,62,64,66,68,69,71,73,75,76,78,79,81,82,84,85,87,88,90,91,92,93,95,96,97,98,99,100,101,103,104,104,105,106,107,108,109,110,111,111,112,113,114,114,115,116,116,117,117,118,118,119,120,120,120,121,121,122,122,122,123,123,124,124,124,124,125,125,125,125,126,126,126,126,126,127,127,127,127,127,127,127,127,127,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 10,13,16,18,21,23,26,28,31,33,36,38,40,43,45,47,49,51,53,55,57,59,61,63,65,67,69,70,72,74,75,77,79,80,82,83,85,86,87,89,90,91,93,94,95,96,97,99,100,101,102,103,104,105,106,107,107,108,109,110,111,111,112,113,114,114,115,116,116,117,117,118,118,119,119,120,120,121,121,122,122,122,123,123,123,124,124,124,125,125,125,125,126,126,126,126,126,126,127,127,127,127,127,127,127,127,127,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 23,26,28,31,33,35,37,40,42,44,46,48,50,52,54,56,58,60,62,64,65,67,69,70,72,74,75,77,78,80,81,83,84,86,87,88,89,91,92,93,94,95,97,98,99,100,101,102,103,104,105,106,106,107,108,109,110,110,111,112,113,113,114,115,115,116,116,117,117,118,119,119,119,120,120,121,121,122,122,122,123,123,123,124,124,124,124,125,125,125,125,126,126,126,126,126,126,127,127,127,127,127,127,127,127,127,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 43,45,47,49,51,53,55,56,58,60,62,63,65,67,68,70,71,73,74,76,77,79,80,81,83,84,85,87,88,89,90,91,92,94,95,96,97,98,99,100,101,102,103,103,104,105,106,107,108,108,109,110,111,111,112,113,113,114,114,115,116,116,117,117,118,118,119,119,119,120,120,121,121,121,122,122,123,123,123,123,124,124,124,124,125,125,125,125,126,126,126,126,126,126,127,127,127,127,127,127,127,127,127,127,127,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 68,70,71,72,74,75,76,78,79,80,81,82,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,101,102,103,104,105,105,106,107,107,108,109,109,110,111,111,112,112,113,114,114,115,115,116,116,117,117,118,118,118,119,119,120,120,120,121,121,121,122,122,122,123,123,123,123,124,124,124,124,125,125,125,125,125,126,126,126,126,126,126,126,127,127,127,127,127,127,127,127,127,127,127,127,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
.db 97,98,99,99,100,101,101,102,103,103,104,104,105,106,106,107,107,108,108,109,110,110,111,111,112,112,112,113,113,114,114,115,115,115,116,116,117,117,117,118,118,118,119,119,119,120,120,120,121,121,121,121,122,122,122,122,123,123,123,123,123,124,124,124,124,124,125,125,125,125,125,125,125,126,126,126,126,126,126,126,126,127,127,127,127,127,127,127,127,127,127,127,127,127,127,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128
